NAME
IWL::InputButton - a input button
INHERITANCE
IWL::Object -> IWL::Widget -> IWL::Input -> IWL::InputButton
DESCRIPTION
The InputButton provides a regular input of type button
CONSTRUCTOR
IWL::InputButton->new ([%ARGS])
Where %ARGS is an optional hash parameter with with key-values. submit: set to true if the input should be of type 'submit'
METHODS
- setLabel (TEXT)
-
Sets the text of the label for the button. This is an alias to the setValue method.
Parameter: TEXT - the text.
- getLabel
-
Returns the label of the button
LICENCE AND COPYRIGHT
Copyright (c) 2006-2007 Viktor Kojouharov. All rights reserved.
This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself. See perldoc perlartistic.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
1 POD Error
The following errors were encountered while parsing the POD:
- Around line 89:
You forgot a '=back' before '=head1'